"use strict";

exports.__esModule = true;
exports.sourceNodes = exports.createSchemaCustomization = void 0;

var _fetch = require("./utils/fetch");

var normalize = _interopRequireWildcard(require("./utils/normalize"));

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const createSchemaCustomization = async ({
  actions
}, {
  subDomain
}) => {
  const {
    createFieldExtension,
    createTypes
  } = actions; // Create URL Fields

  createFieldExtension({
    name: "apply_url",

    extend(options, prevFieldConfig) {
      return {
        resolve(source) {
          return `${subDomain}/apply/jobs/details/${source.board_code}`;
        }

      };
    }

  });
  createFieldExtension({
    name: "custom_apply_url",

    extend(options, prevFieldConfig) {
      return {
        resolve(source) {
          return `${subDomain}/apply/${source.board_code}/${normalize.slugify(source.title)}`;
        }

      };
    }

  });
  const typeDefs = `
        type jazzHr implements Node {
            jazzhr_id: String
            title: String
            recruiter: String
            board_code: String
            department: String
            hiring_lead: String
            team_id: String
            state: String
            city: String
            zip: String
            description: String
            minimum_salary: String
            maximum_salary: String
            type: String
            notes: String
            original_open_date: String
            send_to_job_boards: String
            internal_code: String
            status: String
            questionnaire: String
            apply_url: String @apply_url
            custom_apply_url: String @custom_apply_url
        }
    `;
  createTypes(typeDefs);
};

exports.createSchemaCustomization = createSchemaCustomization;

const sourceNodes = async ({
  actions,
  getNode,
  store,
  cache,
  createNodeId,
  createContentDigest
}, {
  apiKey,
  verboseOutput
}) => {
  const {
    createNode
  } = actions;
  let entities = await (0, _fetch.getApiData)({
    apiKey,
    verboseOutput
  }); // Normalize data & create nodes
  //
  // Creates entities from object collections of entities

  entities = normalize.normalizeEntities(entities); // Standardizes ids & cleans keys

  entities = normalize.standardizeKeys(entities); // Converts to use only GMT dates

  entities = normalize.standardizeDates(entities); // creates Gatsby IDs for each entity

  entities = normalize.createGatsbyIds(createNodeId, entities); // creates nodes for each entry

  normalize.createNodesFromEntities({
    entities,
    createNode,
    createContentDigest
  });
  return;
};

exports.sourceNodes = sourceNodes;